# Satellite Scraper
Easy to use python package for scraping high-resolution satellite images from apple maps.🌎

## Features
  - Provides super high resolution satellite images of a specified area!
  - No need for any api key.

## How it Works:
  - Takes a free API key from sattelites.pro
  - Uses API key to download an array of high-res tiles from apple maps.
  - Stiches the array togehter to produce one high resolution image.



